@@ -135,6 +135,31 @@ setGeneric("Views", signature="subject",
 )
 
 
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### Views() methods for integer and numeric
+###
+### Note that these methods are effectively implemented in the XVector
+### package!
+
+setMethod("Views", "integer",
+    function(subject, start=NULL, end=NULL, width=NULL, names=NULL)
+    {
+        S4Vectors:::load_package_gracefully("XVector", "by the Views() ",
+                                            "method for integer vectors")
+        callGeneric()
+    }
+)
+
+setMethod("Views", "numeric",
+    function(subject, start=NULL, end=NULL, width=NULL, names=NULL)
+    {
+        S4Vectors:::load_package_gracefully("XVector", "by the Views() ",
+                                            "method for numeric vectors")
+        callGeneric()
+    }
+)
+
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### unlist()
 ###
@@ -326,9 +351,8 @@ setMethod("viewApply", "Views",
                       ...),
               simplify = simplify)
         if (!simplify) {
-            ans <- S4Vectors:::new_SimpleList_from_list("SimpleList", ans,
-                                                        metadata = metadata(X),
-                                                        mcols = mcols(X, use.names=FALSE))
+            ans <- as(ans, "CompressedList")
+            mcols(ans) <- mcols(X, use.names=FALSE)
         }
         ans
     }
@@ -346,10 +370,10 @@ setGeneric("viewWhichMins", signature="x",
            function(x, na.rm = FALSE) standardGeneric("viewWhichMins"))
 setGeneric("viewWhichMaxs", signature="x",
            function(x, na.rm = FALSE) standardGeneric("viewWhichMaxs"))
-setGeneric("viewRangeMaxs",
-           function(x, na.rm = FALSE) standardGeneric("viewRangeMaxs"))
 setGeneric("viewRangeMins",
            function(x, na.rm = FALSE) standardGeneric("viewRangeMins"))
+setGeneric("viewRangeMaxs",
+           function(x, na.rm = FALSE) standardGeneric("viewRangeMaxs"))
 
 setMethod("Summary", "Views", function(x, ..., na.rm = FALSE) {
   viewSummaryFunMap <- list(min = viewMins, max = viewMaxs, sum = viewSums)
